Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Group ¶
type Group[T any] struct { // contains filtered or unexported fields }
Group is a struct that holds a slice of items and a function to execute on them. The function is executed when the slice reaches its capacity. The function is executed concurrently with a limit of concurrency.
Click to show internal directories.
Click to hide internal directories.